<?php
/*
 * $Id: blocks.php,v 1.4 2005/03/16 16:12:13 tohokuaiki Exp $
 * Copyright (c) 2003 by Jeremy N. Cowgar <jc@cowgar.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * You may not change or alter any portion of this comment or credits
 * of supporting developers from this source code or any supporting
 * source code which is considered copyrighted (c) material of the
 * original comment or credit authors.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

define('_MB_RECENT_EDIT_NUMBER_OF_ENTRIES','Nero de ingresos a mostrar');
define('_MB_WEBLOG_EDIT_LINK_TO_LIST', 'Link authors to their entries? (0=No,1=Yes)'); //eng
define('_MB_RECENT_EDIT_MAX_TITLE_LENGTH','Mima longitud del tulo');
define('_MB_RECENT_EDIT_DATE_FORMAT','Formato de la fecha');
define('_MB_RECENT_EDIT_USE_AVATARS','Usar avatars? (0=No,1=Si)');
define('_MB_RECENT_EDIT_TYPE','Tipo (1=peque,2=mediano,3=largo)');

define('_MB_WEBLOG_LANG_TITLE', 'Title'); // eng
define('_MB_WEBLOG_LANG_AUTHOR', 'Author'); // eng
define('_MB_WEBLOG_LANG_COMMENTS', 'Comments'); // eng
define('_MB_WEBLOG_LANG_POSTED', 'Posted'); // eng
define('_MB_WEBLOG_LANG_READS', 'Reads'); // eng
define('_MB_WEBLOG_LANG_MOREWEBLOGS', 'More weBLogs'); // eng

?>